=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2009-05-09 17:16:28 +0000
+++ bzrlib/branch.py	2009-05-10 01:26:54 +0000
@@ -884,7 +884,7 @@
         inter = InterBranch.get(self, target)
         lossy_push = getattr(inter, "lossy_push", None)
         if lossy_push is None:
-            raise errors.DpushToNative(target)
+            raise errors.LossyPushToSameVCS(self, target)
         return lossy_push(stop_revision)
 
     def basis_tree(self):

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2009-05-09 16:53:46 +0000
+++ bzrlib/errors.py	2009-05-10 01:26:54 +0000
@@ -3027,9 +3027,13 @@
         self.repository = repository
 
 
-class DpushToNative(BzrError):
-
-    _fmt = "%(branch)r is not a foreign branch, use regular push."
-
-    def __init__(self, branch):
-        self.branch = branch
+class LossyPushToSameVCS(BzrError):
+
+    _fmt = ("Lossy push not possible between %(source_branch)r and "
+            "%(target_branch)r that are in the same VCS.")
+
+    internal_error = True
+
+    def __init__(self, source_branch, target_branch):
+        self.source_branch = source_branch
+        self.target_branch = target_branch

=== modified file 'bzrlib/foreign.py'
--- bzrlib/foreign.py	2009-05-09 17:16:28 +0000
+++ bzrlib/foreign.py	2009-05-10 01:26:54 +0000
@@ -329,7 +329,11 @@
         target_branch = bzrdir.open_branch()
         target_branch.lock_write()
         try:
-            revid_map = source_branch.lossy_push(target_branch)
+            try:
+                revid_map = source_branch.lossy_push(target_branch)
+            except errors.LossyPushToSameVCS:
+                raise BzrCommandError("%r is not a foreign branch, use regular "
+                                      "push." % target_branch)
             # We successfully created the target, remember it
             if source_branch.get_push_location() is None or remember:
                 source_branch.set_push_location(target_branch.base)

